summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvassprite_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvassprite_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvassprite_imp.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/kjsembed/qtbindings/qcanvassprite_imp.cpp b/kjsembed/qtbindings/qcanvassprite_imp.cpp
index 6268e75c..7d9898b3 100644
--- a/kjsembed/qtbindings/qcanvassprite_imp.cpp
+++ b/kjsembed/qtbindings/qcanvassprite_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvassprite_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasSpriteImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -66,8 +66,8 @@ void QCanvasSpriteImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
EnumValue enums[] = {
// enum FrameAnimationType
- { "Cycle", QCanvasSprite::Cycle },
- { "Oscillate", QCanvasSprite::Oscillate },
+ { "Cycle", TQCanvasSprite::Cycle },
+ { "Oscillate", TQCanvasSprite::Oscillate },
{ 0, 0 }
};
@@ -115,7 +115,7 @@ void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -128,25 +128,25 @@ void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QCanvasSprite pointer from an Object.
*/
-QCanvasSprite *QCanvasSpriteImp::toQCanvasSprite( KJS::Object &self )
+TQCanvasSprite *QCanvasSpriteImp::toQCanvasSprite( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasSprite *>( obj );
+ return dynamic_cast<TQCanvasSprite *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QCanvasSprite" )
+ if ( op->typeName() != "TQCanvasSprite" )
return 0;
- return op->toNative<QCanvasSprite>();
+ return op->toNative<TQCanvasSprite>();
}
/**
@@ -164,7 +164,7 @@ KJS::Object QCanvasSpriteImp::construct( KJS::ExecState *exec, const KJS::List &
break;
}
- QString msg = i18n("QCanvasSpriteCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QCanvasSpriteCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -172,20 +172,20 @@ KJS::Object QCanvasSpriteImp::construct( KJS::ExecState *exec, const KJS::List &
KJS::Object QCanvasSpriteImp::QCanvasSprite_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter QCanvasPixmapArray *
return KJS::Object();
- QCanvasPixmapArray * arg0; // Dummy
+ TQCanvasPixmapArray * arg0; // Dummy
- // Unsupported parameter QCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- QCanvas * arg1; // Dummy
+ TQCanvas * arg1; // Dummy
- // We should now create an instance of the QCanvasSprite object
+ // We should now create an instance of the TQCanvasSprite object
- QCanvasSprite *ret = new QCanvasSprite(
+ TQCanvasSprite *ret = new TQCanvasSprite(
arg0,
arg1 );
@@ -303,7 +303,7 @@ KJS::Value QCanvasSpriteImp::call( KJS::ExecState *exec, KJS::Object &self, cons
break;
}
- QString msg = i18n( "QCanvasSpriteImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasSpriteImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -311,10 +311,10 @@ KJS::Value QCanvasSpriteImp::call( KJS::ExecState *exec, KJS::Object &self, cons
KJS::Value QCanvasSpriteImp::setSequence_2( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter QCanvasPixmapArray *
return KJS::Value();
- QCanvasPixmapArray * arg0; // Dummy
+ TQCanvasPixmapArray * arg0; // Dummy
instance->setSequence(
arg0 );
@@ -367,7 +367,7 @@ KJS::Value QCanvasSpriteImp::setFrame_6( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QCanvasSpriteImp::setFrameAnimation_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QCanvasSprite::FrameAnimationType arg0 = QCanvasSprite::Cycle; // TODO (hack for QCanvasSprite)
+ TQCanvasSprite::FrameAnimationType arg0 = TQCanvasSprite::Cycle; // TODO (hack for TQCanvasSprite)
int arg1 = extractInt(exec, args, 1);
@@ -411,10 +411,10 @@ KJS::Value QCanvasSpriteImp::rtti_10( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QCanvasSpriteImp::collidesWith_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const QCanvasItem *
return KJS::Value();
- const QCanvasItem * arg0; // Dummy
+ const TQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -425,7 +425,7 @@ KJS::Value QCanvasSpriteImp::collidesWith_11( KJS::ExecState *exec, KJS::Object
KJS::Value QCanvasSpriteImp::boundingRect_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QRect ret;
+ TQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
@@ -538,7 +538,7 @@ KJS::Value QCanvasSpriteImp::image_23( KJS::ExecState *exec, KJS::Object &obj, c
{
instance->image( );
- return KJS::Value(); // Returns 'QCanvasPixmap *'
+ return KJS::Value(); // Returns 'TQCanvasPixmap *'
}
@@ -546,7 +546,7 @@ KJS::Value QCanvasSpriteImp::imageAdvanced_24( KJS::ExecState *exec, KJS::Object
{
instance->imageAdvanced( );
- return KJS::Value(); // Returns 'QCanvasPixmap *'
+ return KJS::Value(); // Returns 'TQCanvasPixmap *'
}
@@ -557,7 +557,7 @@ KJS::Value QCanvasSpriteImp::image_25( KJS::ExecState *exec, KJS::Object &obj, c
instance->image(
arg0 );
- return KJS::Value(); // Returns 'QCanvasPixmap *'
+ return KJS::Value(); // Returns 'TQCanvasPixmap *'
}
@@ -575,7 +575,7 @@ KJS::Value QCanvasSpriteImp::advance_26( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value QCanvasSpriteImp::draw_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- QPainter arg0; // TODO (hack for qcanvas)
+ TQPainter arg0; // TODO (hack for qcanvas)
instance->draw(
arg0 );
@@ -128,25 +128,25 @@ void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QCanvasSprite pointer from an Object.
+ * Extract a TQCanvasSprite pointer from an Object.
*/
@@ -172,20 +172,20 @@ KJS::Object QCanvasSpriteImp::construct( KJS::ExecState *exec, const KJS::List &
KJS::Object QCanvasSpriteImp::QCanvasSprite_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter QCanvasPixmapArray *
+ // Unsupported parameter TQCanvasPixmapArray *
return KJS::Object();
@@ -311,10 +311,10 @@ KJS::Value QCanvasSpriteImp::call( KJS::ExecState *exec, KJS::Object &self, cons
KJS::Value QCanvasSpriteImp::setSequence_2( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QCanvasPixmapArray *
+ // Unsupported parameter TQCanvasPixmapArray *
return KJS::Value();
@@ -411,10 +411,10 @@ KJS::Value QCanvasSpriteImp::rtti_10( KJS::ExecState *exec, KJS::Object &obj, co
KJS::Value QCanvasSpriteImp::collidesWith_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const QCanvasItem *
+ // Unsupported parameter const TQCanvasItem *
return KJS::Value();